@@ -12,7 +12,7 @@ def generate():
 def serve():
 	'''Serves site up'''
 	generate()
-	os.chdir(muon.static.SITEDIR)
+	os.chdir(muon.static.c.sitedir)
 	try:
 		port = 8000
 		Handler = SimpleHTTPServer.SimpleHTTPRequestHandler
